unit Unit2;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls, TeEngine, Series, TeeProcs, Chart,
  VclTee.TeeGDIPlus;

type
  TForm1 = class(TForm)
    Panel1: TPanel;
    Image1: TImage;
    Button1: TButton;
    Chart1: TChart;
    Series1: TBarSeries;
    lblChartVersion: TLabel;
    procedure Button1Click(Sender: TObject);
  private
    procedure UpdateImage;
    { Private declarations }
  public
    { Public declarations }
    constructor Create(aOwner: TComponent); override;
  end;

var
  Form1: TForm1;

implementation

uses
  TeeConst;

{$R *.dfm}

constructor TForm1.Create(aOwner: TComponent);
var
  I: Integer;
  lSrs: TBarSeries;
begin
  inherited;

  for I := 1 to 5 do
  begin
    lSrs := TBarSeries.Create(self);
    lSrs.ParentChart := Chart1;
    lSrs.Title := 'Series #' + Inttostr(I);
    lSrs.Marks.Visible := false;
    lSrs.FillSampleValues(7);
  end;

  lblChartVersion.Caption := TeeMsg_Version;
end;


procedure AssignChartToGraphic(aChart: TChart; const aRect: TRect; aGraphic: TGraphic);
var
//  {$ifdef Debug}
//  lFileName: string;
//  lPNG: TPNGExportFormat;
//  lEMF: TEMFExportFormat;
//  lFS: TFileStream;
//  {$endif}  // Debug
  lHoldShadow: boolean;
  I: Integer;
  lBoolArray: array of boolean;
  lHoldBevel: TPanelBevel;
  lHoldColor: TColor;
  lHoldGradientVisible: boolean;
  lMetafile: TMetafile;
  lBmp: TBitmap;
begin

  lHoldGradientVisible := aChart.Gradient.Visible;
  lHoldColor := aChart.Color;
  lHoldBevel := aChart.BevelOuter;
  lHoldShadow := aChart.Shadow.Visible;


  try
    SetLength(lBoolArray, aChart.SeriesCount);
    for I := 0 to aChart.SeriesCount - 1 do    // Iterate
      if aChart.Series[I] is TPieSeries then
      begin
        lBoolArray[I] := TPieSeries(aChart.Series[I]).Circled;
        TPieSeries(aChart.Series[I]).Circled := True;
      end
      else
        lBoolArray[I] := True;


    aChart.Gradient.Visible  := false;
    aChart.Color := clWhite;
    aChart.BevelOuter := bvNone;
    aChart.Shadow.Visible := False;

    if aGraphic is TMetafile then
    begin
      {$ifdef Debug}
      lMetafile := aChart.TeeCreateMetafile(True, aRect);
      {$else}
      lMetafile := aChart.TeeCreateMetafile(false, aRect);
      {$endif}
      try
        aGraphic.Assign(lMetafile);
        {$ifdef CodeSite}
        if CSLogging then
          CodeSite.Send('Chart Metafile', lMetafile);
        {$endif}

      finally
        lMetafile.Free;
      end;
    end
    else
    begin
      lBmp := aChart.TeeCreateBitmap(clWhite, aRect);
      try
        aGraphic.Assign(lBmp);
        {$ifdef CodeSite}
        if CSLogging then
          CodeSite.Send('Chart Bitmap', lBmp);
        {$endif}
      finally
        lBmp.Free;
      end;
    end;
  finally
    aChart.Shadow.Visible := lHoldShadow;
    aChart.Gradient.Visible := lHoldGradientVisible;
    aChart.Color := lHoldColor;
    aChart.BevelOuter := lHoldBevel;
    for I := 0 to aChart.SeriesCount - 1 do    // Iterate
      if aChart.Series[I] is TPieSeries then
        TPieSeries(aChart.Series[I]).Circled := lBoolArray[I];
  end;
end;

procedure TForm1.Button1Click(Sender: TObject);
begin
  UpdateImage;
end;

procedure TForm1.UpdateImage;
var
  lBmp: TBitmap;
begin
  lBmp := TBitmap.Create;
  lBmp.Width := Image1.Width;
  lBmp.Height := Image1.Height;
  Image1.Picture.Graphic := lBmp;
  lBmp.Free;
  AssignChartToGraphic(Chart1, Rect(1, 1, Image1.Width, Image1.Height), Image1.Picture.Graphic);
end;



end.
